@@ -648,38 +648,48 @@ is_candidate_for_mimetypes( const NAIContext *object, guint target, GList *files
 			gchar *ftype, *fgroup, *fsubgroup;
 			gboolean match, positive;
 
-			ftype = na_selected_info_get_mime_type( NA_SELECTED_INFO( it->data ));
-			split_mimetype( ftype, &fgroup, &fsubgroup );
 			match = FALSE;
+			ftype = na_selected_info_get_mime_type( NA_SELECTED_INFO( it->data ));
 
-			for( im = mimetypes ; im && ok ; im = im->next ){
-				const gchar *imtype = ( const gchar * ) im->data;
-				positive = is_positive_assertion( imtype );
+			if( ftype ){
+				split_mimetype( ftype, &fgroup, &fsubgroup );
 
-				if( !positive || !match ){
-					if( is_mimetype_of( positive ? imtype : imtype+1, fgroup, fsubgroup )){
-						if( positive ){
-							match = TRUE;
-						} else {
-							ok = FALSE;
+				for( im = mimetypes ; im && ok ; im = im->next ){
+					const gchar *imtype = ( const gchar * ) im->data;
+					positive = is_positive_assertion( imtype );
+
+					if( !positive || !match ){
+						if( is_mimetype_of( positive ? imtype : imtype+1, fgroup, fsubgroup )){
+							g_debug( "%s: condition=%s, positive=%s, ftype=%s, fgroup=%s, fsubgroup=%s, matched",
+									thisfn, imtype, positive ? "True":"False", ftype, fgroup, fsubgroup );
+							if( positive ){
+								match = TRUE;
+							} else {
+								ok = FALSE;
+							}
 						}
 					}
 				}
-			}
 
-			ok &= match;
+				if( !match ){
+					gchar *mimetypes_str = na_core_utils_slist_to_text( mimetypes );
+					g_debug( "%s: no positive match found for Mimetypes=%s", thisfn, mimetypes_str );
+					g_free( mimetypes_str );
+					ok = FALSE;
+				}
+
+			} else {
+				gchar *uri = na_selected_info_get_uri( NA_SELECTED_INFO( it->data ));
+				g_debug( "%s: null mimetype found for %s", thisfn, uri );
+				g_free( uri );
+				ok = FALSE;
+			}
 
 			g_free( fsubgroup );
 			g_free( fgroup );
 			g_free( ftype );
 		}
 
-		if( !ok ){
-			gchar *mimetypes_str = na_core_utils_slist_to_text( mimetypes );
-			g_debug( "%s: object is not candidate because Mimetypes=%s", thisfn, mimetypes_str );
-			g_free( mimetypes_str );
-		}
-
 		na_core_utils_slist_free( mimetypes );
 	}
 
@@ -698,6 +708,10 @@ is_mimetype_of( const gchar *mimetype, const gchar *fgroup, const gchar *fsubgro
 	gboolean is_type_of;
 	gchar *mgroup, *msubgroup;
 
+	if( !strcmp( mimetype, "*" ) || !strcmp( mimetype, "*/*" )){
+		return( TRUE );
+	}
+
 	split_mimetype( mimetype, &mgroup, &msubgroup );
 
 	is_type_of = ( strcmp( fgroup, mgroup ) == 0 );
@@ -739,13 +753,20 @@ is_candidate_for_basenames( const NAIContext *object, guint target, GList *files
 			gboolean matchcase = na_object_get_matchcase( object );
 			GSList *ib;
 			GList *it;
+			gchar *tmp;
 
 			for( it = files ; it && ok ; it = it->next ){
 				gchar *pattern, *bname, *bname_utf8;
 				gboolean match, positive;
+				gchar *pattern_utf8;
 
 				bname = na_selected_info_get_basename( NA_SELECTED_INFO( it->data ));
 				bname_utf8 = g_filename_to_utf8( bname, -1, NULL, NULL, NULL );
+				if( !matchcase ){
+					tmp = g_ascii_strdown( bname_utf8, g_utf8_strlen( bname_utf8, -1 ));
+					g_free( bname_utf8 );
+					bname_utf8 = tmp;
+				}
 				match = FALSE;
 
 				for( ib = basenames ; ib && ok ; ib = ib->next ){
@@ -753,9 +774,12 @@ is_candidate_for_basenames( const NAIContext *object, guint target, GList *files
 						g_strdup(( gchar * ) ib->data ) :
 						g_ascii_strdown(( gchar * ) ib->data, strlen(( gchar * ) ib->data ));
 					positive = is_positive_assertion( pattern );
+					pattern_utf8 = g_filename_to_utf8( positive ? pattern : pattern+1, -1, NULL, NULL, NULL );
 
 					if( !positive || !match ){
-						if( g_pattern_match_simple( positive ? pattern : pattern+1, bname_utf8 )){
+						if( g_pattern_match_simple( pattern_utf8, bname_utf8 )){
+							g_debug( "%s: condition=%s, positive=%s, basename=%s: matched",
+									thisfn, pattern_utf8, positive ? "True":"False", bname_utf8 );
 							if( positive ){
 								match = TRUE;
 							} else {
@@ -764,22 +788,22 @@ is_candidate_for_basenames( const NAIContext *object, guint target, GList *files
 						}
 					}
 
+					g_free( pattern_utf8 );
 					g_free( pattern );
 				}
 
-				ok &= match;
+				if( !match ){
+					gchar *basenames_str = na_core_utils_slist_to_text( basenames );
+					g_debug( "%s: no positive match found for Basenames=%s", thisfn, basenames_str );
+					g_free( basenames_str );
+					ok = FALSE;
+				}
 
 				g_free( bname_utf8 );
 				g_free( bname );
 			}
 		}
 
-		if( !ok ){
-			gchar *basenames_str = na_core_utils_slist_to_text( basenames );
-			g_debug( "%s: object is not candidate because Basenames=%s", thisfn, basenames_str );
-			g_free( basenames_str );
-		}
-
 		na_core_utils_slist_free( basenames );
 	}
 
@@ -847,7 +871,7 @@ is_candidate_for_schemes( const NAIContext *object, guint target, GList *files )
 			GList *it;
 
 			for( it = files ; it && ok ; it = it->next ){
-				gchar *scheme = na_selected_info_get_uri_scheme( NA_SELECTED_INFO( files->data ));
+				gchar *scheme = na_selected_info_get_uri_scheme( NA_SELECTED_INFO( it->data ));
 
 				if( na_core_utils_slist_count( distincts, scheme ) == 0 ){
 					GSList *is;
@@ -929,13 +953,16 @@ is_candidate_for_folders( const NAIContext *object, guint target, GList *files )
 			GList *it;
 
 			for( it = files ; it && ok ; it = it->next ){
-				gchar *dirname = na_selected_info_get_dirname( NA_SELECTED_INFO( files->data ));
+				gchar *dirname = na_selected_info_get_dirname( NA_SELECTED_INFO( it->data ));
 
 				if( na_core_utils_slist_count( distincts, dirname ) == 0 ){
+					g_debug( "%s: distinct dirname=%s", thisfn, dirname );
+
 					GSList *id;
-					gchar *dirname_utf8;
+					gchar *dirname_utf8, *pattern_utf8;
 					const gchar *pattern;
 					gboolean match, positive;
+					gboolean has_pattern;
 
 					distincts = g_slist_prepend( distincts, g_strdup( dirname ));
 					dirname_utf8 = g_filename_to_utf8( dirname, -1, NULL, NULL, NULL );
@@ -944,16 +971,25 @@ is_candidate_for_folders( const NAIContext *object, guint target, GList *files )
 					for( id = folders ; id && ok ; id = id->next ){
 						pattern = ( const gchar * ) id->data;
 						positive = is_positive_assertion( pattern );
+						pattern_utf8 = g_filename_to_utf8( positive ? pattern : pattern+1, -1, NULL, NULL, NULL );
+						has_pattern = ( g_strstr_len( pattern_utf8, -1, "*" ) != NULL );
 
 						if( !positive || !match ){
-							if( g_pattern_match_simple( positive ? pattern : pattern+1, dirname_utf8 )){
+							if(( has_pattern && g_pattern_match_simple( pattern_utf8, dirname_utf8 )) || g_str_has_prefix( dirname_utf8, pattern_utf8 )){
+								g_debug( "%s: condition=%s, positive=%s: matched",
+										thisfn, pattern, positive ? "True":"False" );
 								if( positive ){
 									match = TRUE;
 								} else {
 									ok = FALSE;
 								}
+							/*} else {
+								g_debug( "%s: condition=%s, positive=%s: not matched",
+										thisfn, pattern_utf8, positive ? "True":"False" );*/
 							}
 						}
+
+						g_free( pattern_utf8 );
 					}
 
 					ok &= match;
